==> easyflu-0.0.1.tar.gz: lib/config/const.dart <==
import 'package:event_bus/event_bus.dart';
import 'package:flutter/material.dart';
import 'package:easyflu/base/base_view_state.dart';
import 'package:easyflu/easyflu.dart';
import 'package:easyflu/http/http_data.dart';
import 'package:easyflu/utils/win_media.dart';
import 'package:easyflu/widget/widget_template.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';


final EventBus publicEventBus = EventBus();

int startPage = 1;

int pageLimit = 10;

bool centerTitle = true;

double defMargin = 15;

Color primaryColor = Colors.blue;

BuildContext? context = Get.context;

double appBarHeight = kToolbarHeight;

double appbarHMargin = 15;

bool useOriginSize = true;

const String defPassword = "@#\$0142365987CDKJDIEWQD@#\$%\^&!!";

const String rsaSplit = "------------$defPassword-------------";

/// **********************************************Widget配置*************************************************************************************/

///loading
Widget get pageLoading => SpinKitWave(color: Theme.of(context!!).primaryColor, type: SpinKitWaveType.start, size: getSp(24)!,);

///错误布局
ViewStateWidgetBuilder errorWidget = (BaseViewState viewStateModel) => buildNoDataWidget(viewStateModel: viewStateModel);


ViewStateWidgetBuilder emptyWidget = (BaseViewState viewStateModel) => buildNoDataWidget(viewStateModel: viewStateModel);

/// **********************************************设置网络错误提示*************************************************************************************/


String HTTP_TIMEOUT_MSG = "网络连接超时，请检查网络设置";
String HTTP_ERROR_MSG = "服务器异常，请稍后重试！";
String CANCEL_MSG = "请求已被取消，请稍后重试！";
String NO_DATA_MSG = '无数据';
String UNAUTHORIZED_MSG = '未允许授权';
String NETWORK_ERROR_MSG = '网络错误';
String SSL_ERROR_MSG = '证书错误';
String UNKNOWN_MSG = '未知错误';
String HTTP_INCORRECT_MSG = '请求错误';
String PARSE_ERROR_MSG = '数据解析错误';

/// **********************************************公用key*************************************************************************************/
const String loginKey = 'loginKey';

const String userKey = 'userKey';

const String themeKey = 'themeKey';

const kThemeUserDarkMode = 'kThemeUserDarkMode';

const kThemeColor = 'kThemeColor';




/// **********************************************自定义方法名*************************************************************************************/
typedef ViewStateModelWidgetBuilder<T> = Widget Function(T? value);

typedef ViewStateModelWidgetListBuilder<T> = List<Widget> Function(T? value);

typedef ViewStateWidgetBuilder = Widget Function(BaseViewState viewStateModel);

typedef ViewPortBuilder = void Function(int firstIndex, int lastIndex);

typedef ValidateResponse = dynamic Function(dynamic data);

typedef GetxViewStateModelWidgetBuilder<T> = Widget Function(BuildContext context, T model);

typedef DioWidgetBuilder = Widget Function(HttpData httpData);

==> easyflu-0.0.7.tar.gz: lib/config/const.dart <==
import 'package:event_bus/event_bus.dart';
import 'package:flutter/material.dart';
import 'package:easyflu/base/base_view_state.dart';
import 'package:easyflu/easyflu.dart';
import 'package:easyflu/http/http_data.dart';
import 'package:easyflu/utils/win_media.dart';
import 'package:easyflu/widget/widget_template.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';


final EventBus publicEventBus = EventBus();

int startPage = 1;

int pageLimit = 10;

bool centerTitle = true;

double defMargin = 15;

Color primaryColor = Colors.blue;

BuildContext? context = Get.context;

double appBarHeight = kToolbarHeight;

double appbarHMargin = 15;

bool useOriginSize = true;

const String defPassword = "@#\$0142365987CDKJDIEWQD@#\$%\^&!!";

const String rsaSplit = "------------$defPassword-------------";

/// **********************************************Widget配置*************************************************************************************/

///loading
Widget get pageLoading => SpinKitWave(type: SpinKitWaveType.start, size: getSp(24)!,);

///错误布局
ViewStateWidgetBuilder errorWidget = (BaseViewState viewStateModel) => buildNoDataWidget(viewStateModel: viewStateModel);


ViewStateWidgetBuilder emptyWidget = (BaseViewState viewStateModel) => buildNoDataWidget(viewStateModel: viewStateModel);

/// **********************************************设置网络错误提示*************************************************************************************/


String HTTP_TIMEOUT_MSG = "网络连接超时，请检查网络设置";
String HTTP_ERROR_MSG = "服务器异常，请稍后重试！";
String CANCEL_MSG = "请求已被取消，请稍后重试！";
String NO_DATA_MSG = '无数据';
String UNAUTHORIZED_MSG = '未允许授权';
String NETWORK_ERROR_MSG = '网络错误';
String SSL_ERROR_MSG = '证书错误';
String UNKNOWN_MSG = '未知错误';
String HTTP_INCORRECT_MSG = '请求错误';
String PARSE_ERROR_MSG = '数据解析错误';

/// **********************************************公用key*************************************************************************************/
const String loginKey = 'loginKey';

const String userKey = 'userKey';

const String themeKey = 'themeKey';

const kThemeUserDarkMode = 'kThemeUserDarkMode';

const kThemeColor = 'kThemeColor';




/// **********************************************自定义方法名*************************************************************************************/
typedef ViewStateModelWidgetBuilder<T> = Widget Function(T? value);

typedef ViewStateModelWidgetListBuilder<T> = List<Widget> Function(T? value);

typedef ViewStateWidgetBuilder = Widget Function(BaseViewState viewStateModel);

typedef ViewPortBuilder = void Function(int firstIndex, int lastIndex);

typedef ValidateResponse = dynamic Function(dynamic data);

typedef GetxViewStateModelWidgetBuilder<T> = Widget Function(BuildContext context, T model);

typedef DioWidgetBuilder = Widget Function(HttpData httpData);
